@@ -1,7 +1,7 @@
 import abc
 import logging
 import time
-from typing import Callable
+from typing import Callable, List
 from time import localtime, strftime
 
 from bluepy import btle
@@ -12,12 +12,14 @@ _LOGGER = logging.getLogger(__name__)
 
 class TionDelegation(DefaultDelegate):
     def __init__(self):
-        self._data = None
+        self._data: List = []
+        self.__topic = None
         DefaultDelegate.__init__(self)
 
     def handleNotification(self, handle: int, data: bytes):
-        self._data = data
+        self._data.append(data)
         _LOGGER.debug("Got data in %d response %s", handle, bytes(data).hex())
+        self.__topic.read()
 
     def handleDiscovery(self, dev, isNewDev, isNewData):
         if isNewDev:
@@ -25,9 +27,16 @@ class TionDelegation(DefaultDelegate):
         elif isNewData:
             _LOGGER.debug("Received new data from %s", dev.addr)
 
+    def setReadTopic(self, topic):
+        self.__topic = topic
+
     @property
     def data(self) -> bytes:
-        return self._data
+        return self._data.pop(0)
+
+    @property
+    def haveNewData(self) -> bool:
+        return len(self._data) > 0
 
 
 class TionException(Exception):
@@ -54,7 +63,7 @@ class TionDummy:
     def _disconnect_dummy():
         return
 
-    def _get_data_from_breezer_dummy(self, keep_connection: bool = False) -> bytearray:
+    def _get_data_from_breezer_dummy(self) -> bytearray:
         return self._dummy_data
 
     @staticmethod
@@ -212,7 +221,7 @@ class tion(TionDummy):
         """
         try:
             self._connect()
-            response = self._get_data_from_breezer(keep_connection)
+            response = self._get_data_from_breezer()
         finally:
             if not keep_connection:
                 self._disconnect()
@@ -352,6 +361,7 @@ class tion(TionDummy):
         _LOGGER.debug("Result is %s", result)
         self._btle.withDelegate(self._delegation)
         self.notify.read()
+        self._delegation.setReadTopic(self.notify)
 
     @property
     def fan_speed(self):
